@@ -71,13 +71,50 @@ PorseleinApp.stopBounce = function ()
     document.addEventListener('touchmove',function(e) {
         var xMovement = Math.abs(e.touches[0].screenX - xStart);
         var yMovement = Math.abs(e.touches[0].screenY - yStart);
-        
-        /*
+        //console.log("mov: " + xMovement + " / " + yMovement);
+        if (xMovement <= yMovement)
+        {
+            e.preventDefault();
+        }
+    });
+};
+
+PorseleinApp.selfScroll = function ()
+{
+    var xStart, yStart = 0;
+    var speed = 0;
+    var innerWidth = $('.h_scroll').innerWidth();
+    var dragged = false;
+
+    document.addEventListener('touchstart',function(e) {
         xStart = e.touches[0].screenX;
         yStart = e.touches[0].screenY;
+        $('.h_scroll').stop();
+        innerWidth = $('.h_scroll').innerWidth();
+        speed = 0;
+        var dragged = false;
+    });
+    
+    document.addEventListener('touchmove',function(e) {
+        var dragged = true;
+        
+        var xMovement = e.touches[0].screenX - xStart;
+        var yMovement = e.touches[0].screenY - yStart;
+        
+        xStart = e.touches[0].screenX;
+        yStart = e.touches[0].screenY;
+        if (xMovement < 5 && xMovement > -5)
+        {
+            speed = 0;
+        }
+        else
+        {
+            speed = xMovement * 5;
+        }
+        
     
         var xScroll = 0;
-        var currentValue = $('.h_scroll').css("margin-left");
+        var currentValue = $('.h_scroll').css("left");
         
         //console.log("XMovement: " + xMovement);
         if(typeof currentValue !== 'undefined')
@@ -89,27 +126,59 @@ PorseleinApp.stopBounce = function ()
             xScroll = xMovement ;
         }
         
-        if(xScroll > -($('.h_scroll').width() - screen.width) && xScroll <= 0 )
+        
+        //console.log("Screen width: " + screen.width);
+        //console.log("xScroll: " + xScroll);
+        //console.log("h_scroll width: " + ($('.h_scroll').innerWidth()));
+        
+        if(xScroll > -(innerWidth - screen.width) && xScroll <= 0 )
         {
-            $('.h_scroll').css("margin-left", xScroll);
+            $('.h_scroll').css("left", xScroll);
         }
         
         e.preventDefault();
-        */
-        
-        
-        //console.log("mov: " + xMovement + " / " + yMovement);
-        if (xMovement <= yMovement)
+    });
+    
+    document.addEventListener('click',function(e) {
+        if (dragged)
         {
             e.preventDefault();
         }
+    });
+    
+    document.addEventListener('touchend',function(e) {
         
+        if (speed == 0)
+        {
+            return true;
+        }
+        var currentValue = parseInt($('.h_scroll').css("left").replace("px", ""));
+        var finalValue = currentValue + speed;
+        
+        console.log("Animating!");
+        console.log("Speed = " + speed);
+        console.log("currentValue = " + currentValue);
+        console.log("finalValue = " + finalValue);
+        
+        if (finalValue >= 0)
+        {
+            finalValue = 0;
+        }
+        else if (finalValue < -(innerWidth - screen.width))
+        {
+            finalValue = -(innerWidth - screen.width)
+        }
+        
+        $('.h_scroll').animate({"left": finalValue}, Math.abs(speed)+500, "easeOutCirc");
+        
+        e.preventDefault();
     });
 };
 
 $(function(){
     PorseleinApp.fixLinks();
     PorseleinApp.stopBounce();
+    //PorseleinApp.selfScroll();
 });
 
 
